@@ -19,7 +19,12 @@ from .. import (
     SampleReadmeProps as _SampleReadmeProps_3518b03b,
 )
 from ..deps import Dependency as _Dependency_8c19c91d
-from ..github import AutoApproveOptions as _AutoApproveOptions_dac86cbe
+from ..github import (
+    AutoApproveOptions as _AutoApproveOptions_dac86cbe,
+    AutoMergeOptions as _AutoMergeOptions_d112cd3c,
+    GitHubOptions as _GitHubOptions_21553699,
+    StaleOptions as _StaleOptions_929db764,
+)
 from ..tasks import Task as _Task_fb843092
 
 
@@ -50,21 +55,27 @@ class JavaProject(
         test_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
         name: builtins.str,
         auto_approve_options: typing.Optional[_AutoApproveOptions_dac86cbe] = None,
+        auto_merge_options: typing.Optional[_AutoMergeOptions_d112cd3c] = None,
         clobber: typing.Optional[builtins.bool] = None,
         dev_container: typing.Optional[builtins.bool] = None,
+        github: typing.Optional[builtins.bool] = None,
+        github_options: typing.Optional[_GitHubOptions_21553699] = None,
         gitpod: typing.Optional[builtins.bool] = None,
         logging: typing.Optional[_LoggerOptions_eb0f6309] = None,
+        mergify: typing.Optional[builtins.bool] = None,
         outdir: typing.Optional[builtins.str] = None,
         parent: typing.Optional[_Project_57d89203] = None,
         project_type: typing.Optional[_ProjectType_fd80c725] = None,
         readme: typing.Optional[_SampleReadmeProps_3518b03b] = None,
+        stale: typing.Optional[builtins.bool] = None,
+        stale_options: typing.Optional[_StaleOptions_929db764] = None,
+        vscode: typing.Optional[builtins.bool] = None,
         artifact_id: builtins.str,
         group_id: builtins.str,
         version: builtins.str,
         description: typing.Optional[builtins.str] = None,
         packaging: typing.Optional[builtins.str] = None,
         url: typing.Optional[builtins.str] = None,
-        mergify: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param compile_options: (experimental) Compile options. Default: - defaults
@@ -80,21 +91,27 @@ class JavaProject(
         :param test_deps: (experimental) List of test dependencies for this project. Dependencies use the format: ``<groupId>/<artifactId>@<semver>`` Additional dependencies can be added via ``project.addTestDependency()``. Default: []
         :param name: (experimental) This is the name of your project. Default: $BASEDIR
         :param auto_approve_options: (experimental) Enable and configure the 'auto approve' workflow. Default: - auto approve is disabled
+        :param auto_merge_options: (experimental) Configure options for automatic merging on GitHub. Has no effect if ``github.mergify`` is set to false. Default: - see defaults in ``AutoMergeOptions``
         :param clobber: (experimental) Add a ``clobber`` task which resets the repo to origin. Default: true
         :param dev_container: (experimental) Add a VSCode development environment (used for GitHub Codespaces). Default: false
+        :param github: (experimental) Enable GitHub integration. Enabled by default for root projects. Disabled for non-root projects. Default: true
+        :param github_options: (experimental) Options for GitHub integration. Default: - see GitHubOptions
         :param gitpod: (experimental) Add a Gitpod development environment. Default: false
         :param logging: (experimental) Configure logging options such as verbosity. Default: {}
+        :param mergify: (deprecated) Whether mergify should be enabled on this repository or not. Default: true
         :param outdir: (experimental) The root directory of the project. Relative to this directory, all files are synthesized. If this project has a parent, this directory is relative to the parent directory and it cannot be the same as the parent or any of it's other sub-projects. Default: "."
         :param parent: (experimental) The parent project, if this project is part of a bigger project.
         :param project_type: (experimental) Which type of project this is (library/app). Default: ProjectType.UNKNOWN
         :param readme: (experimental) The README setup. Default: - { filename: 'README.md', contents: '# replace this' }
+        :param stale: (experimental) Auto-close of stale issues and pull request. See ``staleOptions`` for options. Default: true
+        :param stale_options: (experimental) Auto-close stale issues and pull requests. To disable set ``stale`` to ``false``. Default: - see defaults in ``StaleOptions``
+        :param vscode: (experimental) Enable VSCode integration. Enabled by default for root projects. Disabled for non-root projects. Default: true
         :param artifact_id: (experimental) The artifactId is generally the name that the project is known by. Although the groupId is important, people within the group will rarely mention the groupId in discussion (they are often all be the same ID, such as the MojoHaus project groupId: org.codehaus.mojo). It, along with the groupId, creates a key that separates this project from every other project in the world (at least, it should :) ). Along with the groupId, the artifactId fully defines the artifact's living quarters within the repository. In the case of the above project, my-project lives in $M2_REPO/org/codehaus/mojo/my-project. Default: "my-app"
         :param group_id: (experimental) This is generally unique amongst an organization or a project. For example, all core Maven artifacts do (well, should) live under the groupId org.apache.maven. Group ID's do not necessarily use the dot notation, for example, the junit project. Note that the dot-notated groupId does not have to correspond to the package structure that the project contains. It is, however, a good practice to follow. When stored within a repository, the group acts much like the Java packaging structure does in an operating system. The dots are replaced by OS specific directory separators (such as '/' in Unix) which becomes a relative directory structure from the base repository. In the example given, the org.codehaus.mojo group lives within the directory $M2_REPO/org/codehaus/mojo. Default: "org.acme"
         :param version: (experimental) This is the last piece of the naming puzzle. groupId:artifactId denotes a single project but they cannot delineate which incarnation of that project we are talking about. Do we want the junit:junit of 2018 (version 4.12), or of 2007 (version 3.8.2)? In short: code changes, those changes should be versioned, and this element keeps those versions in line. It is also used within an artifact's repository to separate versions from each other. my-project version 1.0 files live in the directory structure $M2_REPO/org/codehaus/mojo/my-project/1.0. Default: "0.1.0"
         :param description: (experimental) Description of a project is always good. Although this should not replace formal documentation, a quick comment to any readers of the POM is always helpful. Default: undefined
         :param packaging: (experimental) Project packaging format. Default: "jar"
         :param url: (experimental) The URL, like the name, is not required. This is a nice gesture for projects users, however, so that they know where the project lives. Default: undefined
-        :param mergify: (experimental) Whether mergify should be enabled on this repository or not. Default: true
 
         :stability: experimental
         '''
@@ -112,21 +129,27 @@ class JavaProject(
             test_deps=test_deps,
             name=name,
             auto_approve_options=auto_approve_options,
+            auto_merge_options=auto_merge_options,
             clobber=clobber,
             dev_container=dev_container,
+            github=github,
+            github_options=github_options,
             gitpod=gitpod,
             logging=logging,
+            mergify=mergify,
             outdir=outdir,
             parent=parent,
             project_type=project_type,
             readme=readme,
+            stale=stale,
+            stale_options=stale_options,
+            vscode=vscode,
             artifact_id=artifact_id,
             group_id=group_id,
             version=version,
             description=description,
             packaging=packaging,
             url=url,
-            mergify=mergify,
         )
 
         jsii.create(JavaProject, self, [options])
@@ -1266,17 +1289,23 @@ class ProjenrcOptions:
     jsii_type="projen.java.JavaProjectOptions",
     jsii_struct_bases=[_ProjectOptions_0d5b93c6, PomOptions],
     name_mapping={
-        "mergify": "mergify",
         "name": "name",
         "auto_approve_options": "autoApproveOptions",
+        "auto_merge_options": "autoMergeOptions",
         "clobber": "clobber",
         "dev_container": "devContainer",
+        "github": "github",
+        "github_options": "githubOptions",
         "gitpod": "gitpod",
         "logging": "logging",
+        "mergify": "mergify",
         "outdir": "outdir",
         "parent": "parent",
         "project_type": "projectType",
         "readme": "readme",
+        "stale": "stale",
+        "stale_options": "staleOptions",
+        "vscode": "vscode",
         "artifact_id": "artifactId",
         "group_id": "groupId",
         "version": "version",
@@ -1300,17 +1329,23 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
     def __init__(
         self,
         *,
-        mergify: typing.Optional[builtins.bool] = None,
         name: builtins.str,
         auto_approve_options: typing.Optional[_AutoApproveOptions_dac86cbe] = None,
+        auto_merge_options: typing.Optional[_AutoMergeOptions_d112cd3c] = None,
         clobber: typing.Optional[builtins.bool] = None,
         dev_container: typing.Optional[builtins.bool] = None,
+        github: typing.Optional[builtins.bool] = None,
+        github_options: typing.Optional[_GitHubOptions_21553699] = None,
         gitpod: typing.Optional[builtins.bool] = None,
         logging: typing.Optional[_LoggerOptions_eb0f6309] = None,
+        mergify: typing.Optional[builtins.bool] = None,
         outdir: typing.Optional[builtins.str] = None,
         parent: typing.Optional[_Project_57d89203] = None,
         project_type: typing.Optional[_ProjectType_fd80c725] = None,
         readme: typing.Optional[_SampleReadmeProps_3518b03b] = None,
+        stale: typing.Optional[builtins.bool] = None,
+        stale_options: typing.Optional[_StaleOptions_929db764] = None,
+        vscode: typing.Optional[builtins.bool] = None,
         artifact_id: builtins.str,
         group_id: builtins.str,
         version: builtins.str,
@@ -1331,17 +1366,23 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
     ) -> None:
         '''(experimental) Options for ``JavaProject``.
 
-        :param mergify: (experimental) Whether mergify should be enabled on this repository or not. Default: true
         :param name: (experimental) This is the name of your project. Default: $BASEDIR
         :param auto_approve_options: (experimental) Enable and configure the 'auto approve' workflow. Default: - auto approve is disabled
+        :param auto_merge_options: (experimental) Configure options for automatic merging on GitHub. Has no effect if ``github.mergify`` is set to false. Default: - see defaults in ``AutoMergeOptions``
         :param clobber: (experimental) Add a ``clobber`` task which resets the repo to origin. Default: true
         :param dev_container: (experimental) Add a VSCode development environment (used for GitHub Codespaces). Default: false
+        :param github: (experimental) Enable GitHub integration. Enabled by default for root projects. Disabled for non-root projects. Default: true
+        :param github_options: (experimental) Options for GitHub integration. Default: - see GitHubOptions
         :param gitpod: (experimental) Add a Gitpod development environment. Default: false
         :param logging: (experimental) Configure logging options such as verbosity. Default: {}
+        :param mergify: (deprecated) Whether mergify should be enabled on this repository or not. Default: true
         :param outdir: (experimental) The root directory of the project. Relative to this directory, all files are synthesized. If this project has a parent, this directory is relative to the parent directory and it cannot be the same as the parent or any of it's other sub-projects. Default: "."
         :param parent: (experimental) The parent project, if this project is part of a bigger project.
         :param project_type: (experimental) Which type of project this is (library/app). Default: ProjectType.UNKNOWN
         :param readme: (experimental) The README setup. Default: - { filename: 'README.md', contents: '# replace this' }
+        :param stale: (experimental) Auto-close of stale issues and pull request. See ``staleOptions`` for options. Default: true
+        :param stale_options: (experimental) Auto-close stale issues and pull requests. To disable set ``stale`` to ``false``. Default: - see defaults in ``StaleOptions``
+        :param vscode: (experimental) Enable VSCode integration. Enabled by default for root projects. Disabled for non-root projects. Default: true
         :param artifact_id: (experimental) The artifactId is generally the name that the project is known by. Although the groupId is important, people within the group will rarely mention the groupId in discussion (they are often all be the same ID, such as the MojoHaus project groupId: org.codehaus.mojo). It, along with the groupId, creates a key that separates this project from every other project in the world (at least, it should :) ). Along with the groupId, the artifactId fully defines the artifact's living quarters within the repository. In the case of the above project, my-project lives in $M2_REPO/org/codehaus/mojo/my-project. Default: "my-app"
         :param group_id: (experimental) This is generally unique amongst an organization or a project. For example, all core Maven artifacts do (well, should) live under the groupId org.apache.maven. Group ID's do not necessarily use the dot notation, for example, the junit project. Note that the dot-notated groupId does not have to correspond to the package structure that the project contains. It is, however, a good practice to follow. When stored within a repository, the group acts much like the Java packaging structure does in an operating system. The dots are replaced by OS specific directory separators (such as '/' in Unix) which becomes a relative directory structure from the base repository. In the example given, the org.codehaus.mojo group lives within the directory $M2_REPO/org/codehaus/mojo. Default: "org.acme"
         :param version: (experimental) This is the last piece of the naming puzzle. groupId:artifactId denotes a single project but they cannot delineate which incarnation of that project we are talking about. Do we want the junit:junit of 2018 (version 4.12), or of 2007 (version 3.8.2)? In short: code changes, those changes should be versioned, and this element keeps those versions in line. It is also used within an artifact's repository to separate versions from each other. my-project version 1.0 files live in the directory structure $M2_REPO/org/codehaus/mojo/my-project/1.0. Default: "0.1.0"
@@ -1364,10 +1405,16 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         '''
         if isinstance(auto_approve_options, dict):
             auto_approve_options = _AutoApproveOptions_dac86cbe(**auto_approve_options)
+        if isinstance(auto_merge_options, dict):
+            auto_merge_options = _AutoMergeOptions_d112cd3c(**auto_merge_options)
+        if isinstance(github_options, dict):
+            github_options = _GitHubOptions_21553699(**github_options)
         if isinstance(logging, dict):
             logging = _LoggerOptions_eb0f6309(**logging)
         if isinstance(readme, dict):
             readme = _SampleReadmeProps_3518b03b(**readme)
+        if isinstance(stale_options, dict):
+            stale_options = _StaleOptions_929db764(**stale_options)
         if isinstance(compile_options, dict):
             compile_options = MavenCompileOptions(**compile_options)
         if isinstance(junit_options, dict):
@@ -1382,18 +1429,24 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
             "group_id": group_id,
             "version": version,
         }
-        if mergify is not None:
-            self._values["mergify"] = mergify
         if auto_approve_options is not None:
             self._values["auto_approve_options"] = auto_approve_options
+        if auto_merge_options is not None:
+            self._values["auto_merge_options"] = auto_merge_options
         if clobber is not None:
             self._values["clobber"] = clobber
         if dev_container is not None:
             self._values["dev_container"] = dev_container
+        if github is not None:
+            self._values["github"] = github
+        if github_options is not None:
+            self._values["github_options"] = github_options
         if gitpod is not None:
             self._values["gitpod"] = gitpod
         if logging is not None:
             self._values["logging"] = logging
+        if mergify is not None:
+            self._values["mergify"] = mergify
         if outdir is not None:
             self._values["outdir"] = outdir
         if parent is not None:
@@ -1402,6 +1455,12 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
             self._values["project_type"] = project_type
         if readme is not None:
             self._values["readme"] = readme
+        if stale is not None:
+            self._values["stale"] = stale
+        if stale_options is not None:
+            self._values["stale_options"] = stale_options
+        if vscode is not None:
+            self._values["vscode"] = vscode
         if description is not None:
             self._values["description"] = description
         if packaging is not None:
@@ -1431,17 +1490,6 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         if test_deps is not None:
             self._values["test_deps"] = test_deps
 
-    @builtins.property
-    def mergify(self) -> typing.Optional[builtins.bool]:
-        '''(experimental) Whether mergify should be enabled on this repository or not.
-
-        :default: true
-
-        :stability: experimental
-        '''
-        result = self._values.get("mergify")
-        return typing.cast(typing.Optional[builtins.bool], result)
-
     @builtins.property
     def name(self) -> builtins.str:
         '''(experimental) This is the name of your project.
@@ -1466,6 +1514,20 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         result = self._values.get("auto_approve_options")
         return typing.cast(typing.Optional[_AutoApproveOptions_dac86cbe], result)
 
+    @builtins.property
+    def auto_merge_options(self) -> typing.Optional[_AutoMergeOptions_d112cd3c]:
+        '''(experimental) Configure options for automatic merging on GitHub.
+
+        Has no effect if
+        ``github.mergify`` is set to false.
+
+        :default: - see defaults in ``AutoMergeOptions``
+
+        :stability: experimental
+        '''
+        result = self._values.get("auto_merge_options")
+        return typing.cast(typing.Optional[_AutoMergeOptions_d112cd3c], result)
+
     @builtins.property
     def clobber(self) -> typing.Optional[builtins.bool]:
         '''(experimental) Add a ``clobber`` task which resets the repo to origin.
@@ -1488,6 +1550,30 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         result = self._values.get("dev_container")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def github(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Enable GitHub integration.
+
+        Enabled by default for root projects. Disabled for non-root projects.
+
+        :default: true
+
+        :stability: experimental
+        '''
+        result = self._values.get("github")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def github_options(self) -> typing.Optional[_GitHubOptions_21553699]:
+        '''(experimental) Options for GitHub integration.
+
+        :default: - see GitHubOptions
+
+        :stability: experimental
+        '''
+        result = self._values.get("github_options")
+        return typing.cast(typing.Optional[_GitHubOptions_21553699], result)
+
     @builtins.property
     def gitpod(self) -> typing.Optional[builtins.bool]:
         '''(experimental) Add a Gitpod development environment.
@@ -1510,6 +1596,19 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         result = self._values.get("logging")
         return typing.cast(typing.Optional[_LoggerOptions_eb0f6309], result)
 
+    @builtins.property
+    def mergify(self) -> typing.Optional[builtins.bool]:
+        '''(deprecated) Whether mergify should be enabled on this repository or not.
+
+        :default: true
+
+        :deprecated: use ``githubOptions.mergify`` instead
+
+        :stability: deprecated
+        '''
+        result = self._values.get("mergify")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def outdir(self) -> typing.Optional[builtins.str]:
         '''(experimental) The root directory of the project.
@@ -1564,6 +1663,45 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         result = self._values.get("readme")
         return typing.cast(typing.Optional[_SampleReadmeProps_3518b03b], result)
 
+    @builtins.property
+    def stale(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Auto-close of stale issues and pull request.
+
+        See ``staleOptions`` for options.
+
+        :default: true
+
+        :stability: experimental
+        '''
+        result = self._values.get("stale")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def stale_options(self) -> typing.Optional[_StaleOptions_929db764]:
+        '''(experimental) Auto-close stale issues and pull requests.
+
+        To disable set ``stale`` to ``false``.
+
+        :default: - see defaults in ``StaleOptions``
+
+        :stability: experimental
+        '''
+        result = self._values.get("stale_options")
+        return typing.cast(typing.Optional[_StaleOptions_929db764], result)
+
+    @builtins.property
+    def vscode(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Enable VSCode integration.
+
+        Enabled by default for root projects. Disabled for non-root projects.
+
+        :default: true
+
+        :stability: experimental
+        '''
+        result = self._values.get("vscode")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def artifact_id(self) -> builtins.str:
         '''(experimental) The artifactId is generally the name that the project is known by.
