@@ -27,30 +27,30 @@ class Task(metaclass=jsii.JSIIMeta, jsii_type="projen.tasks.Task"):
         name: builtins.str,
         *,
         exec: typing.Optional[builtins.str] = None,
-        category: typing.Optional["TaskCategory"] = None,
         condition: typing.Optional[builtins.str] = None,
         cwd: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        required_env: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
         :param name: -
         :param exec: (experimental) Shell command to execute as the first command of the task. Default: - add steps using ``task.exec(command)`` or ``task.spawn(subtask)``
-        :param category: (experimental) Category for start menu. Default: TaskCategory.MISC
         :param condition: (experimental) A shell command which determines if the this task should be executed. If the program exits with a zero exit code, steps will be executed. A non-zero code means that task will be skipped.
         :param cwd: (experimental) The working directory for all steps in this task (unless overridden by the step). Default: - process.cwd()
         :param description: (experimental) The description of this build command. Default: - the task name
         :param env: (experimental) Defines environment variables for the execution of this task. Values in this map will be evaluated in a shell, so you can do stuff like ``$(echo "foo")``. Default: {}
+        :param required_env: (experimental) A set of environment variables that must be defined in order to execute this task. Task execution will fail if one of these is not defined.
 
         :stability: experimental
         '''
         props = TaskOptions(
             exec=exec,
-            category=category,
             condition=condition,
             cwd=cwd,
             description=description,
             env=env,
+            required_env=required_env,
         )
 
         jsii.create(Task, self, [name, props])
@@ -261,15 +261,6 @@ class Task(metaclass=jsii.JSIIMeta, jsii_type="projen.tasks.Task"):
         '''
         return typing.cast(typing.List["TaskStep"], jsii.get(self, "steps"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="category")
-    def category(self) -> typing.Optional["TaskCategory"]:
-        '''(experimental) The start menu category of the task.
-
-        :stability: experimental
-        '''
-        return typing.cast(typing.Optional["TaskCategory"], jsii.get(self, "category"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="condition")
     def condition(self) -> typing.Optional[builtins.str]:
@@ -292,67 +283,37 @@ class Task(metaclass=jsii.JSIIMeta, jsii_type="projen.tasks.Task"):
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
 
 
-@jsii.enum(jsii_type="projen.tasks.TaskCategory")
-class TaskCategory(enum.Enum):
-    '''
-    :stability: experimental
-    '''
-
-    BUILD = "BUILD"
-    '''
-    :stability: experimental
-    '''
-    TEST = "TEST"
-    '''
-    :stability: experimental
-    '''
-    RELEASE = "RELEASE"
-    '''
-    :stability: experimental
-    '''
-    MAINTAIN = "MAINTAIN"
-    '''
-    :stability: experimental
-    '''
-    MISC = "MISC"
-    '''
-    :stability: experimental
-    '''
-
-
 @jsii.data_type(
     jsii_type="projen.tasks.TaskCommonOptions",
     jsii_struct_bases=[],
     name_mapping={
-        "category": "category",
         "condition": "condition",
         "cwd": "cwd",
         "description": "description",
         "env": "env",
+        "required_env": "requiredEnv",
     },
 )
 class TaskCommonOptions:
     def __init__(
         self,
         *,
-        category: typing.Optional[TaskCategory] = None,
         condition: typing.Optional[builtins.str] = None,
         cwd: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        required_env: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
-        :param category: (experimental) Category for start menu. Default: TaskCategory.MISC
         :param condition: (experimental) A shell command which determines if the this task should be executed. If the program exits with a zero exit code, steps will be executed. A non-zero code means that task will be skipped.
         :param cwd: (experimental) The working directory for all steps in this task (unless overridden by the step). Default: - process.cwd()
         :param description: (experimental) The description of this build command. Default: - the task name
         :param env: (experimental) Defines environment variables for the execution of this task. Values in this map will be evaluated in a shell, so you can do stuff like ``$(echo "foo")``. Default: {}
+        :param required_env: (experimental) A set of environment variables that must be defined in order to execute this task. Task execution will fail if one of these is not defined.
 
         :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {}
-        if category is not None:
-            self._values["category"] = category
         if condition is not None:
             self._values["condition"] = condition
         if cwd is not None:
@@ -361,17 +322,8 @@ class TaskCommonOptions:
             self._values["description"] = description
         if env is not None:
             self._values["env"] = env
-
-    @builtins.property
-    def category(self) -> typing.Optional[TaskCategory]:
-        '''(experimental) Category for start menu.
-
-        :default: TaskCategory.MISC
-
-        :stability: experimental
-        '''
-        result = self._values.get("category")
-        return typing.cast(typing.Optional[TaskCategory], result)
+        if required_env is not None:
+            self._values["required_env"] = required_env
 
     @builtins.property
     def condition(self) -> typing.Optional[builtins.str]:
@@ -421,6 +373,17 @@ class TaskCommonOptions:
         result = self._values.get("env")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
+    @builtins.property
+    def required_env(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''(experimental) A set of environment variables that must be defined in order to execute this task.
+
+        Task execution will fail if one of these is not defined.
+
+        :stability: experimental
+        '''
+        result = self._values.get("required_env")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -437,11 +400,11 @@ class TaskCommonOptions:
     jsii_type="projen.tasks.TaskOptions",
     jsii_struct_bases=[TaskCommonOptions],
     name_mapping={
-        "category": "category",
         "condition": "condition",
         "cwd": "cwd",
         "description": "description",
         "env": "env",
+        "required_env": "requiredEnv",
         "exec": "exec",
     },
 )
@@ -449,26 +412,24 @@ class TaskOptions(TaskCommonOptions):
     def __init__(
         self,
         *,
-        category: typing.Optional[TaskCategory] = None,
         condition: typing.Optional[builtins.str] = None,
         cwd: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        required_env: typing.Optional[typing.Sequence[builtins.str]] = None,
         exec: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param category: (experimental) Category for start menu. Default: TaskCategory.MISC
         :param condition: (experimental) A shell command which determines if the this task should be executed. If the program exits with a zero exit code, steps will be executed. A non-zero code means that task will be skipped.
         :param cwd: (experimental) The working directory for all steps in this task (unless overridden by the step). Default: - process.cwd()
         :param description: (experimental) The description of this build command. Default: - the task name
         :param env: (experimental) Defines environment variables for the execution of this task. Values in this map will be evaluated in a shell, so you can do stuff like ``$(echo "foo")``. Default: {}
+        :param required_env: (experimental) A set of environment variables that must be defined in order to execute this task. Task execution will fail if one of these is not defined.
         :param exec: (experimental) Shell command to execute as the first command of the task. Default: - add steps using ``task.exec(command)`` or ``task.spawn(subtask)``
 
         :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {}
-        if category is not None:
-            self._values["category"] = category
         if condition is not None:
             self._values["condition"] = condition
         if cwd is not None:
@@ -477,20 +438,11 @@ class TaskOptions(TaskCommonOptions):
             self._values["description"] = description
         if env is not None:
             self._values["env"] = env
+        if required_env is not None:
+            self._values["required_env"] = required_env
         if exec is not None:
             self._values["exec"] = exec
 
-    @builtins.property
-    def category(self) -> typing.Optional[TaskCategory]:
-        '''(experimental) Category for start menu.
-
-        :default: TaskCategory.MISC
-
-        :stability: experimental
-        '''
-        result = self._values.get("category")
-        return typing.cast(typing.Optional[TaskCategory], result)
-
     @builtins.property
     def condition(self) -> typing.Optional[builtins.str]:
         '''(experimental) A shell command which determines if the this task should be executed.
@@ -539,6 +491,17 @@ class TaskOptions(TaskCommonOptions):
         result = self._values.get("env")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
+    @builtins.property
+    def required_env(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''(experimental) A set of environment variables that must be defined in order to execute this task.
+
+        Task execution will fail if one of these is not defined.
+
+        :stability: experimental
+        '''
+        result = self._values.get("required_env")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     @builtins.property
     def exec(self) -> typing.Optional[builtins.str]:
         '''(experimental) Shell command to execute as the first command of the task.
@@ -633,11 +596,11 @@ class TaskRuntime(metaclass=jsii.JSIIMeta, jsii_type="projen.tasks.TaskRuntime")
     jsii_type="projen.tasks.TaskSpec",
     jsii_struct_bases=[TaskCommonOptions],
     name_mapping={
-        "category": "category",
         "condition": "condition",
         "cwd": "cwd",
         "description": "description",
         "env": "env",
+        "required_env": "requiredEnv",
         "name": "name",
         "steps": "steps",
     },
@@ -646,21 +609,21 @@ class TaskSpec(TaskCommonOptions):
     def __init__(
         self,
         *,
-        category: typing.Optional[TaskCategory] = None,
         condition: typing.Optional[builtins.str] = None,
         cwd: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        required_env: typing.Optional[typing.Sequence[builtins.str]] = None,
         name: builtins.str,
         steps: typing.Optional[typing.Sequence["TaskStep"]] = None,
     ) -> None:
         '''(experimental) Specification of a single task.
 
-        :param category: (experimental) Category for start menu. Default: TaskCategory.MISC
         :param condition: (experimental) A shell command which determines if the this task should be executed. If the program exits with a zero exit code, steps will be executed. A non-zero code means that task will be skipped.
         :param cwd: (experimental) The working directory for all steps in this task (unless overridden by the step). Default: - process.cwd()
         :param description: (experimental) The description of this build command. Default: - the task name
         :param env: (experimental) Defines environment variables for the execution of this task. Values in this map will be evaluated in a shell, so you can do stuff like ``$(echo "foo")``. Default: {}
+        :param required_env: (experimental) A set of environment variables that must be defined in order to execute this task. Task execution will fail if one of these is not defined.
         :param name: (experimental) Task name.
         :param steps: (experimental) Task steps.
 
@@ -669,8 +632,6 @@ class TaskSpec(TaskCommonOptions):
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
-        if category is not None:
-            self._values["category"] = category
         if condition is not None:
             self._values["condition"] = condition
         if cwd is not None:
@@ -679,20 +640,11 @@ class TaskSpec(TaskCommonOptions):
             self._values["description"] = description
         if env is not None:
             self._values["env"] = env
+        if required_env is not None:
+            self._values["required_env"] = required_env
         if steps is not None:
             self._values["steps"] = steps
 
-    @builtins.property
-    def category(self) -> typing.Optional[TaskCategory]:
-        '''(experimental) Category for start menu.
-
-        :default: TaskCategory.MISC
-
-        :stability: experimental
-        '''
-        result = self._values.get("category")
-        return typing.cast(typing.Optional[TaskCategory], result)
-
     @builtins.property
     def condition(self) -> typing.Optional[builtins.str]:
         '''(experimental) A shell command which determines if the this task should be executed.
@@ -741,6 +693,17 @@ class TaskSpec(TaskCommonOptions):
         result = self._values.get("env")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
+    @builtins.property
+    def required_env(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''(experimental) A set of environment variables that must be defined in order to execute this task.
+
+        Task execution will fail if one of these is not defined.
+
+        :stability: experimental
+        '''
+        result = self._values.get("required_env")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     @builtins.property
     def name(self) -> builtins.str:
         '''(experimental) Task name.
@@ -869,31 +832,31 @@ class Tasks(
         name: builtins.str,
         *,
         exec: typing.Optional[builtins.str] = None,
-        category: typing.Optional[TaskCategory] = None,
         condition: typing.Optional[builtins.str] = None,
         cwd: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        required_env: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> Task:
         '''(experimental) Adds a task to a project.
 
         :param name: The name of the task.
         :param exec: (experimental) Shell command to execute as the first command of the task. Default: - add steps using ``task.exec(command)`` or ``task.spawn(subtask)``
-        :param category: (experimental) Category for start menu. Default: TaskCategory.MISC
         :param condition: (experimental) A shell command which determines if the this task should be executed. If the program exits with a zero exit code, steps will be executed. A non-zero code means that task will be skipped.
         :param cwd: (experimental) The working directory for all steps in this task (unless overridden by the step). Default: - process.cwd()
         :param description: (experimental) The description of this build command. Default: - the task name
         :param env: (experimental) Defines environment variables for the execution of this task. Values in this map will be evaluated in a shell, so you can do stuff like ``$(echo "foo")``. Default: {}
+        :param required_env: (experimental) A set of environment variables that must be defined in order to execute this task. Task execution will fail if one of these is not defined.
 
         :stability: experimental
         '''
         options = TaskOptions(
             exec=exec,
-            category=category,
             condition=condition,
             cwd=cwd,
             description=description,
             env=env,
+            required_env=required_env,
         )
 
         return typing.cast(Task, jsii.invoke(self, "addTask", [name, options]))
@@ -1143,7 +1106,6 @@ class TaskStep(TaskStepOptions):
 
 __all__ = [
     "Task",
-    "TaskCategory",
     "TaskCommonOptions",
     "TaskOptions",
     "TaskRuntime",
